Learn R Programming

workflowsets (version 1.1.0)

option_list: Make a classed list of options

Description

This function returns a named list with an extra class of "workflow_set_options" that has corresponding formatting methods for printing inside of tibbles.

Usage

option_list(...)

Value

A classed list.

Arguments

...

A set of named options (or nothing)

Examples

Run this code
option_list(a = 1, b = 2)
option_list()

Run the code above in your browser using DataLab