fit_best() takes results from tuning many models and fits the workflow
configuration associated with the best performance to the training set.
# S3 method for workflow_set
fit_best(x, metric = NULL, eval_time = NULL, ...)A workflow_set object that has been evaluated
with workflow_map(). Note that the workflow set must have been fitted with
the control option save_workflow = TRUE.
A character string giving the metric to rank results by.
A single numeric time point where dynamic event time
metrics should be chosen (e.g., the time-dependent ROC curve, etc). The
values should be consistent with the values used to create x. The NULL
default will automatically use the first evaluation time used by x.
Additional options to pass to tune::fit_best.
This function is a shortcut for the steps needed to fit the
numerically optimal configuration in a fitted workflow set.
The function ranks results, extracts the tuning result pertaining
to the best result, and then again calls fit_best() (itself a
wrapper) on the tuning result containing the best result.
In pseudocode:
rankings <- rank_results(wf_set, metric, select_best = TRUE)
tune_res <- extract_workflow_set_result(wf_set, rankings$wflow_id[1])
fit_best(tune_res, metric)