option_add() is used to update all of the options in a workflow set.
option_remove() will eliminate specific options across rows.
option_add_parameters() adds a parameter object to the option column
(if parameters are being tuned).
Note that executing a function on the workflow set, such as tune_grid(),
will add any options given to that function to the option column.
These functions do not control options for the individual workflows, such as
the recipe blueprint. When creating a workflow manually, use
workflows::add_model() or workflows::add_recipe() to specify
extra options. To alter these in a workflow set, use
update_workflow_model() or update_workflow_recipe().