powered by
This function returns a named list with an extra class of "workflow_set_options" that has corresponding formatting methods for printing inside of tibbles.
"workflow_set_options"
option_list(...)
A classed list.
A set of named options (or nothing)
option_list(a = 1, b = 2) option_list()
Run the code above in your browser using DataLab