A tibble with columns: wflow_id, .config, .metric, mean,
std_err, n, preprocessor, model, and rank.
Arguments
x
A workflow_set object that has been evaluated
with workflow_map().
rank_metric
A character string for a metric.
eval_time
A single numeric time point where dynamic event time
metrics should be chosen (e.g., the time-dependent ROC curve, etc). The
values should be consistent with the values used to create x. The NULL
default will automatically use the first evaluation time used by x.
select_best
A logical giving whether the results should only contain
the numerically best submodel per workflow.
Details
If some models have the exact same performance,
rank(value, ties.method = "random") is used (with a reproducible seed) so
that all ranks are integers.
No columns are returned for the tuning parameters since they are likely to
be different (or not exist) for some models. The wflow_id and .config
columns can be used to determine the corresponding parameter values.