workflow_map() will execute the same function across the workflows in the
set. The various tune_*() functions can be used as well as
tune::fit_resamples().
workflow_map(
object,
fn = "tune_grid",
verbose = FALSE,
seed = sample.int(10^4, 1),
...
)An updated workflow set. The option column will be updated with
any options for the tune package functions given to workflow_map(). Also,
the results will be added to the result column. If the computations for a
workflow fail, a try-catch object will be saved in place of the results
(without stopping execution).
A workflow set.
The name of the function to run, as a character. Acceptable values are:
"tune_grid",
"tune_bayes",
"fit_resamples",
"tune_race_anova",
"tune_race_win_loss", or
"tune_sim_anneal". Note that users need not
provide the namespace or parentheses in this argument,
e.g. provide "tune_grid" rather than "tune::tune_grid" or "tune_grid()".
A logical for logging progress.
A single integer that is set prior to each function execution.
Options to pass to the modeling function. See details below.
When passing options, anything passed in the ... will be combined with any
values in the option column. The values in ... will override that
column's values and the new options are added to the options column.
Any failures in execution result in the corresponding row of results to
contain a try-error object.
In cases where a model has no tuning parameters is mapped to one of the
tuning functions, tune::fit_resamples() will be used instead and a
warning is issued if verbose = TRUE.
If a workflow requires packages that are not installed, a message is printed
and workflow_map() continues with the next workflow (if any).
workflow_set(), as_workflow_set(), extract_workflow_set_result()